==> huaweicloudsdkprojectman-3.0.51-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/metric_request_v2.py <==
# coding: utf-8

import re
import six





class MetricRequestV2:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'date_range': 'str',
        'metric_type': 'str',
        'dividend': 'MetricRequestV2Dividend',
        'divisor': 'object'
    }

    attribute_map = {
        'date_range': 'date_range',
        'metric_type': 'metric_type',
        'dividend': 'dividend',
        'divisor': 'divisor'
    }

    def __init__(self, date_range=None, metric_type=None, dividend=None, divisor=None):
        """MetricRequestV2 - a model defined in huaweicloud sdk"""
        
        

        self._date_range = None
        self._metric_type = None
        self._dividend = None
        self._divisor = None
        self.discriminator = None

        if date_range is not None:
            self.date_range = date_range
        if metric_type is not None:
            self.metric_type = metric_type
        if dividend is not None:
            self.dividend = dividend
        if divisor is not None:
            self.divisor = divisor

    @property
    def date_range(self):
        """Gets the date_range of this MetricRequestV2.

        统计周期

        :return: The date_range of this MetricRequestV2.
        :rtype: str
        """
        return self._date_range

    @date_range.setter
    def date_range(self, date_range):
        """Sets the date_range of this MetricRequestV2.

        统计周期

        :param date_range: The date_range of this MetricRequestV2.
        :type: str
        """
        self._date_range = date_range

    @property
    def metric_type(self):
        """Gets the metric_type of this MetricRequestV2.

        指标类型

        :return: The metric_type of this MetricRequestV2.
        :rtype: str
        """
        return self._metric_type

    @metric_type.setter
    def metric_type(self, metric_type):
        """Sets the metric_type of this MetricRequestV2.

        指标类型

        :param metric_type: The metric_type of this MetricRequestV2.
        :type: str
        """
        self._metric_type = metric_type

    @property
    def dividend(self):
        """Gets the dividend of this MetricRequestV2.


        :return: The dividend of this MetricRequestV2.
        :rtype: MetricRequestV2Dividend
        """
        return self._dividend

    @dividend.setter
    def dividend(self, dividend):
        """Sets the dividend of this MetricRequestV2.


        :param dividend: The dividend of this MetricRequestV2.
        :type: MetricRequestV2Dividend
        """
        self._dividend = dividend

    @property
    def divisor(self):
        """Gets the divisor of this MetricRequestV2.

        指标分母过滤条件

        :return: The divisor of this MetricRequestV2.
        :rtype: object
        """
        return self._divisor

    @divisor.setter
    def divisor(self, divisor):
        """Sets the divisor of this MetricRequestV2.

        指标分母过滤条件

        :param divisor: The divisor of this MetricRequestV2.
        :type: object
        """
        self._divisor = divisor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetricRequestV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.0.54-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/metric_request_v2.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class MetricRequestV2:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'date_range': 'str',
        'metric_type': 'str',
        'dividend': 'MetricRequestV2Dividend',
        'divisor': 'object'
    }

    attribute_map = {
        'date_range': 'date_range',
        'metric_type': 'metric_type',
        'dividend': 'dividend',
        'divisor': 'divisor'
    }

    def __init__(self, date_range=None, metric_type=None, dividend=None, divisor=None):
        """MetricRequestV2 - a model defined in huaweicloud sdk"""
        
        

        self._date_range = None
        self._metric_type = None
        self._dividend = None
        self._divisor = None
        self.discriminator = None

        if date_range is not None:
            self.date_range = date_range
        if metric_type is not None:
            self.metric_type = metric_type
        if dividend is not None:
            self.dividend = dividend
        if divisor is not None:
            self.divisor = divisor

    @property
    def date_range(self):
        """Gets the date_range of this MetricRequestV2.

        统计周期

        :return: The date_range of this MetricRequestV2.
        :rtype: str
        """
        return self._date_range

    @date_range.setter
    def date_range(self, date_range):
        """Sets the date_range of this MetricRequestV2.

        统计周期

        :param date_range: The date_range of this MetricRequestV2.
        :type: str
        """
        self._date_range = date_range

    @property
    def metric_type(self):
        """Gets the metric_type of this MetricRequestV2.

        指标类型

        :return: The metric_type of this MetricRequestV2.
        :rtype: str
        """
        return self._metric_type

    @metric_type.setter
    def metric_type(self, metric_type):
        """Sets the metric_type of this MetricRequestV2.

        指标类型

        :param metric_type: The metric_type of this MetricRequestV2.
        :type: str
        """
        self._metric_type = metric_type

    @property
    def dividend(self):
        """Gets the dividend of this MetricRequestV2.


        :return: The dividend of this MetricRequestV2.
        :rtype: MetricRequestV2Dividend
        """
        return self._dividend

    @dividend.setter
    def dividend(self, dividend):
        """Sets the dividend of this MetricRequestV2.


        :param dividend: The dividend of this MetricRequestV2.
        :type: MetricRequestV2Dividend
        """
        self._dividend = dividend

    @property
    def divisor(self):
        """Gets the divisor of this MetricRequestV2.

        指标分母过滤条件

        :return: The divisor of this MetricRequestV2.
        :rtype: object
        """
        return self._divisor

    @divisor.setter
    def divisor(self, divisor):
        """Sets the divisor of this MetricRequestV2.

        指标分母过滤条件

        :param divisor: The divisor of this MetricRequestV2.
        :type: object
        """
        self._divisor = divisor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetricRequestV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
